@@ -240,6 +240,15 @@ class Client:
             raise IncompleteUpload()
         return chunked_upload.foreign_reference
 
+    def activate_rpc_access(self, user_name: str, api_key: str) -> bool:
+        """
+        Add access to the RPC API for the given user name with the given API key.
+        A new user will be created if none is available with given user name.
+
+        Note: only user with admin privileges can use this.
+        """
+        return self.__call("activate_rpc_access", [user_name, api_key])
+
     def add_collection(self, title: str, parent_id: int = None) -> Union[Dict, None]:
         """
         Create a new collection based on 'title'. If 'parent_id' is set,
@@ -620,12 +629,21 @@ class Client:
         """
         return self.__call("collections", [parent_id, recusive])
 
-    def delete_collection(self, collection_id: int, recursive: bool = False) -> bool:
+    def deactivate_rpc_access(self, user_name: str, api_key: str) -> bool:
+        """
+        Deactivate access to the RPC API for the given user name and API key.
+        Only the access (API key) is removed, not the user.
+
+        Note: only user with admin privileges can use this.
+        """
+        return self.__call("deactivate_rpc_access", [user_name, api_key])
+
+    def delete_collection(self, collection_id: int, recursive: bool = False) -> Dict:
         """
         Delete collection given its id.
 
         Collection MUST be empty of any content (no children collections and no resources),
-        unless the 'recursive' parameter is set to True.
+        unless the 'recursive'parameter is set to True.
         """
         return self.__call("delete_collection", [collection_id, recursive])
 
